"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.namedPayloads = exports.connectPayload = exports.depositWithPayloadLayout = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const layout_items_1 = require("../layout-items");
const vaa_1 = require("../vaa");
//from here: https://github.com/wormhole-foundation/wormhole-circle-integration/blob/105ad59bad687416527003e0241dee4020889341/evm/src/circle_integration/CircleIntegrationMessages.sol#L25
const depositWithPayloadLayout = (customPayload) => [
    (0, layout_items_1.payloadIdItem)(1),
    {
        name: "token",
        binary: "bytes",
        layout: [
            { name: "address", ...layout_items_1.universalAddressItem },
            { name: "amount", ...layout_items_1.amountItem },
        ],
    },
    { name: "sourceDomain", ...layout_items_1.circleDomainItem },
    { name: "targetDomain", ...layout_items_1.circleDomainItem },
    { name: "nonce", ...layout_items_1.circleNonceItem },
    { name: "caller", ...layout_items_1.universalAddressItem },
    { name: "mintRecipient", ...layout_items_1.universalAddressItem },
    (0, sdk_base_1.customizableBytes)({ name: "payload", lengthSize: 2 }, customPayload),
];
exports.depositWithPayloadLayout = depositWithPayloadLayout;
//from here:
//  https://github.com/wormhole-foundation/example-circle-relayer/blob/189becd8d3935decb17383bd2e61b4909cbddc89/evm/src/circle-relayer/CircleRelayerMessages.sol#L16
exports.connectPayload = [
    (0, layout_items_1.payloadIdItem)(1),
    { name: "targetRelayerFee", ...layout_items_1.amountItem },
    { name: "toNativeTokenAmount", ...layout_items_1.amountItem },
    { name: "targetRecipient", ...layout_items_1.universalAddressItem },
];
exports.namedPayloads = [
    ["DepositWithPayload", (0, exports.depositWithPayloadLayout)()],
    ["TransferWithRelay", (0, exports.depositWithPayloadLayout)(exports.connectPayload)],
];
(0, vaa_1.registerPayloadTypes)("AutomaticCircleBridge", exports.namedPayloads);
//# sourceMappingURL=automaticCircleBridge.js.map