"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wormholeEndpointMessage = exports.managerMessageLayout = exports.endpointMessageLayout = exports.nativeTokenTransferLayout = exports.normalizedAmountLayout = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const layout_items_1 = require("../layout-items");
exports.normalizedAmountLayout = [
    { name: "decimals", binary: "uint", size: 1 },
    { name: "amount", binary: "uint", size: 8 },
];
const prefixItem = (prefix) => ({ name: "prefix", binary: "bytes", custom: Uint8Array.from(prefix), omit: true });
exports.nativeTokenTransferLayout = [
    prefixItem([0x99, 0x4E, 0x54, 0x54]),
    { name: "normalizedAmount", binary: "bytes", layout: exports.normalizedAmountLayout },
    { name: "sourceToken", ...layout_items_1.universalAddressItem },
    { name: "recipientAddress", ...layout_items_1.universalAddressItem },
    { name: "recipientChain", ...(0, layout_items_1.chainItem)() },
];
const endpointMessageLayout = (prefix, customPayload) => [
    prefixItem(prefix),
    { name: "sourceManager", ...layout_items_1.universalAddressItem },
    (0, sdk_base_1.customizableBytes)({ name: "managerPayload", lengthSize: 2 }, customPayload),
];
exports.endpointMessageLayout = endpointMessageLayout;
const managerMessageLayout = (customPayload) => [
    { name: "sequence", ...layout_items_1.sequenceItem },
    { name: "sender", ...layout_items_1.universalAddressItem },
    (0, sdk_base_1.customizableBytes)({ name: "payload", lengthSize: 2 }, customPayload),
];
exports.managerMessageLayout = managerMessageLayout;
const wormholeEndpointMessage = (customPayload) => (0, exports.endpointMessageLayout)([0x99, 0x45, 0xFF, 0x10], customPayload);
exports.wormholeEndpointMessage = wormholeEndpointMessage;
//# sourceMappingURL=ntt.js.map